﻿/*
* Description: An Adobe Illustrator script that creates a color guide in PDF format.
* License: This work is licensed under a Creative Commons Attribution-NoDerivatives 4.0 International License. (https://creativecommons.org/licenses/by-nd/4.0/)

* Copyright (c) 2011, Michel Simons
* http://www.no-nonsens.nl
* version 1.02
* November 7th 2011
* August 1th 2017

Under the following terms:

Attribution:
You must give appropriate credit, provide a link to the license, and indicate if changes were made. You may do so in any reasonable manner, but not in any way that suggests the licensor endorses you or your use.

NoDerivatives:
If you remix, transform, or build upon the material, you may not distribute the modified material.

No additional restrictions:
You may not apply legal terms or technological measures that legally restrict others from doing anything the license permits.


Notices:
You do not have to comply with the license for elements of the material in the public domain or where your use is permitted by an applicable exception or limitation.
No warranties are given. The license may not give you all of the permissions necessary for your intended use. For example, other rights such as publicity, privacy, or moral rights may limit how you use the material.

*/

#target illustrator

if (app.name != "Adobe Illustrator") { alert ('This script is created for Adobe Illustrator, it is not developed for or tested on ' + app.name + '. Results can be unexpected and the script most likely will fail on execution.' ); }

// ********************************************************************************************************
// **                                                                                                    **
// ** date format function                                                                               **
// ** http://blog.stevenlevithan.com/archives/date-time-format                                           **
// ********************************************************************************************************
/*
 * Date Format 1.2.3
 * (c) 2007-2009 Steven Levithan <stevenlevithan.com>
 * MIT license
 *
 * Includes enhancements by Scott Trenda <scott.trenda.net>
 * and Kris Kowal <cixar.com/~kris.kowal/>
 *
 * Accepts a date, a mask, or a date and a mask.
 * Returns a formatted version of the given date.
 * The date defaults to the current date/time.
 * The mask defaults to dateFormat.masks.default.
 */

var dateFormat = function () {
	var	token = /d{1,4}|m{1,4}|yy(?:yy)?|([HhMsTt])\1?|[LloSZ]|"[^"]*"|'[^']*'/g,
		timezone = /\b(?:[PMCEA][SDP]T|(?:Pacific|Mountain|Central|Eastern|Atlantic) (?:Standard|Daylight|Prevailing) Time|(?:GMT|UTC)(?:[-+]\d{4})?)\b/g,
		timezoneClip = /[^-+\dA-Z]/g,
		pad = function (val, len) {
			val = String(val);
			len = len || 2;
			while (val.length < len) val = "0" + val;
			return val;
		};

	// Regexes and supporting functions are cached through closure
	return function (date, mask, utc) {
		var dF = dateFormat;

		// You can't provide utc if you skip other args (use the "UTC:" mask prefix)
		if (arguments.length == 1 && Object.prototype.toString.call(date) == "[object String]" && !/\d/.test(date)) {
			mask = date;
			date = undefined;
		}

		// Passing date through Date applies Date.parse, if necessary
		date = date ? new Date(date) : new Date;
		if (isNaN(date)) throw SyntaxError("invalid date");

		mask = String(dF.masks[mask] || mask || dF.masks["default"]);

		// Allow setting the utc argument via the mask
		if (mask.slice(0, 4) == "UTC:") {
			mask = mask.slice(4);
			utc = true;
		}

		var	_ = utc ? "getUTC" : "get",
			d = date[_ + "Date"](),
			D = date[_ + "Day"](),
			m = date[_ + "Month"](),
			y = date[_ + "FullYear"](),
			H = date[_ + "Hours"](),
			M = date[_ + "Minutes"](),
			s = date[_ + "Seconds"](),
			L = date[_ + "Milliseconds"](),
			o = utc ? 0 : date.getTimezoneOffset(),
			flags = {
				d:    d,
				dd:   pad(d),
				ddd:  dF.i18n.dayNames[D],
				dddd: dF.i18n.dayNames[D + 7],
				m:    m + 1,
				mm:   pad(m + 1),
				mmm:  dF.i18n.monthNames[m],
				mmmm: dF.i18n.monthNames[m + 12],
				yy:   String(y).slice(2),
				yyyy: y,
				h:    H % 12 || 12,
				hh:   pad(H % 12 || 12),
				H:    H,
				HH:   pad(H),
				M:    M,
				MM:   pad(M),
				s:    s,
				ss:   pad(s),
				l:    pad(L, 3),
				L:    pad(L > 99 ? Math.round(L / 10) : L),
				t:    H < 12 ? "a"  : "p",
				tt:   H < 12 ? "am" : "pm",
				T:    H < 12 ? "A"  : "P",
				TT:   H < 12 ? "AM" : "PM",
				Z:    utc ? "UTC" : (String(date).match(timezone) || [""]).pop().replace(timezoneClip, ""),
				o:    (o > 0 ? "-" : "+") + pad(Math.floor(Math.abs(o) / 60) * 100 + Math.abs(o) % 60, 4),
				S:    ["th", "st", "nd", "rd"][d % 10 > 3 ? 0 : (d % 100 - d % 10 != 10) * d % 10]
			};

		return mask.replace(token, function ($0) {
			return $0 in flags ? flags[$0] : $0.slice(1, $0.length - 1);
		});
	};
}();

// Some common format strings
dateFormat.masks = {
	"default":      "ddd mmm dd yyyy HH:MM:ss",
	shortDate:      "m/d/yy",
	mediumDate:     "mmm d, yyyy",
	longDate:       "mmmm d, yyyy",
	fullDate:       "dddd, mmmm d, yyyy",
	shortTime:      "h:MM TT",
	mediumTime:     "h:MM:ss TT",
	longTime:       "h:MM:ss TT Z",
	isoDate:        "yyyy-mm-dd",
	isoTime:        "HH:MM:ss",
	isoDateTime:    "yyyy-mm-dd'T'HH:MM:ss",
	isoUtcDateTime: "UTC:yyyy-mm-dd'T'HH:MM:ss'Z'"
};

// Internationalization strings
dateFormat.i18n = {
	dayNames: [
		"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat",
		"Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"
	],
	monthNames: [
		"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
		"January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"
	]
};

// For convenience...
Date.prototype.format = function (mask, utc) {
	return dateFormat(this, mask, utc);
};



// ********************************************************************************************************
// **                                                                                                    **
// ** color settings                                                                                     **
// **                                                                                                    **
// ********************************************************************************************************


var defCol = app.defaultColorSettings; // get the current colorsettings
// strip folders
var filename = unescape(defCol);
filename = filename.substring( filename.lastIndexOf('/') + 1);    // strip path
ColorProfileName = filename.substring (0, filename.lastIndexOf('.') ); // strip .

var CurrentDocumentColorProfileName = "";
var RGBProfile  = "";
var CMYKProfile = "";

var msis_message_2 = "ColorChart.jsx\n\n" +
                     "All copyright (c) 2011 No-Nonsens inc. reserved.\n" +
                     "written by Michel Simons / No-Nonsens inc.\n" +
					 "http://www.no-nonsens.nl\n\n" +
					 "released under Creative Commons Attribution-NoDerivatives 4.0 International License.";

// ********************************************************************************************************
// **                                                                                                    **
// ** default color guide as array                                                                         **
// **                                                                                                    **
// ********************************************************************************************************

var DefaultColorBook = [
// Color Book Block: 1
"0,0,100,0","2,0,43,0","0,0,56,0","0,2,59,0","0,5,47,0","0,4,30,0","0,100,0,0","3,0,53,0","0,1,67,0","0,3,67,0","0,7,55,0","0,7,42,0","100,0,0,0","4,0,73,0","0,3,82,0","0,4,77,0","0,9,64,0","0,15,60,0","0,0,0,100","4,0,90,0","0,5,100,0","0,8,100,0","0,13,100,0","0,22,92,0","0,53,100,0","0,0,100,21","0,8,100,14","0,12,100,20","0,18,100,8","0,18,100,22","0,87,80,0","0,0,100,32","0,4,100,30","0,11,100,30","0,17,100,26","0,15,100,33","100,93,0,5","6,0,100,48","0,2,100,41","0,0,100,47","0,10,100,37","0,9,100,50",
// Color Book Block: 2
"0,3,44,1","0,10,44,0","0,12,40,0","0,15,54,2","0,16,37,0","0,27,49,0","0,5,54,2","0,17,56,0","0,18,49,0","0,22,64,3","0,21,44,0","0,35,64,0","0,10,74,3","0,22,68,0","0,25,63,0","0,28,77,4","0,32,62,0","0,45,90,0","0,26,100,3","0,33,97,0","0,37,92,0","0,44,100,4","0,47,96,0","0,53,100,0","0,27,100,17","0,36,100,8","0,39,100,13","0,42,100,16","0,48,100,7","0,52,100,19","0,20,100,34","0,30,100,27","0,32,100,36","0,36,100,35","0,42,100,20","0,43,100,41","0,5,100,59","0,11,100,58","0,24,100,62","0,8,100,59","0,35,100,38","0,45,100,72",
// Color Book Block: 3
"0,11,29,3","0,23,36,0","0,20,30,0","0,32,42,0","0,25,28,0","0,29,28,0","0,20,40,4","0,32,48,0","0,35,50,0","0,43,57,0","0,42,48,0","0,44,42,0","0,38,64,5","0,45,68,0","0,47,70,0","0,52,71,0","0,58,73,0","0,58,59,0","0,58,100,2","0,54,91,0","0,57,89,0","0,62,94,0","0,65,94,0","0,71,81,0","0,61,100,11","0,55,100,10","0,60,100,6","0,64,100,4","0,67,100,7","0,72,91,0","0,55,100,32","0,49,100,32","0,57,100,16","0,62,100,30","0,66,100,36","0,79,100,16","0,61,100,65","0,49,100,50","0,60,100,60","0,60,100,50","0,71,100,61","0,77,100,53",
// Color Book Block: 4
"0,35,30,0","0,30,22,0","0,25,18,0","0,37,23,0","0,28,13,0","0,21,10,0","0,46,41,0","0,57,46,0","0,44,33,0","0,54,37,0","0,40,22,0","0,45,27,0","0,66,61,0","0,72,63,0","0,62,48,0","0,74,52,0","0,62,40,0","0,77,50,0","0,78,74,0","0,87,80,0","0,100,85,0","0,100,74,0","0,100,68,0","0,100,68,1","0,89,89,3","0,100,88,7","0,100,86,8","0,100,70,12","0,100,67,9","0,100,66,15","0,96,100,22","0,100,90,27","0,100,83,20","0,100,66,32","0,100,62,24","0,100,60,30","0,100,95,53","0,92,100,66","0,100,83,55","0,100,60,56","0,100,57,40","0,100,54,41",
// Color Book Block: 5
"0,35,12,0","0,36,17,0","0,26,4,0","0,43,10,0","0,37,13,0","0,34,5,0","0,56,25,0","0,52,27,0","0,56,20,0","0,61,15,0","0,54,15,0","0,45,8,0","0,76,37,0","0,65,34,0","0,82,31,0","0,83,24,0","0,69,18,0","0,62,10,0","0,100,55,5","0,95,50,0","0,100,40,6","0,100,33,2","0,87,24,0","0,80,12,4","0,100,52,24","0,100,52,8","0,100,38,23","0,100,31,24","0,100,27,11","0,90,6,15","0,100,44,39","0,100,50,26","0,100,32,36","0,100,25,43","0,100,26,30","0,100,12,29","0,100,42,56","0,100,46,55","0,100,33,55","0,100,18,61","0,100,26,45","0,100,15,57",
// Color Book Block: 6
"0,23,2,0","1,28,0,0","5,25,0,0","5,22,0,4","16,36,0,0","17,37,0,2","0,54,0,1","4,39,0,1","10,38,0,0","10,34,0,8","26,50,0,0","26,50,0,4","5,72,0,2","6,51,0,2","21,60,0,0","23,73,0,23","41,75,0,0","38,69,0,10","9,100,0,7","13,91,0,6","29,93,0,0","24,100,0,40","50,100,0,0","41,100,0,23","5,100,0,26","10,100,0,20","30,100,0,2","18,100,0,52","41,100,0,23","39,100,0,35","0,100,0,37","5,100,0,33","31,100,0,15","10,100,0,60","33,100,0,40","35,100,0,45","0,100,5,50","4,100,0,53","15,100,0,55","4,100,0,69","21,100,0,61","25,100,0,56",
// Color Book Block: 7
"21,35,0,4","12,19,0,0","23,30,0,0","26,28,0,2","35,36,0,0","18,14,0,0","30,47,0,7","24,34,0,0","32,41,0,0","37,40,0,4","47,47,0,0","37,32,0,0","46,67,0,14","48,60,0,0","45,53,0,0","47,49,0,8","65,64,0,0","68,62,0,0","61,100,0,20","67,100,0,2","59,66,0,0","80,100,0,27","85,100,0,15","98,100,0,0","57,100,0,31","63,100,0,20","76,100,0,2","75,100,0,40","80,100,0,31","97,100,0,12","54,100,0,41","56,100,0,32","70,100,0,29","75,100,0,56","78,100,0,50","95,100,0,34","49,100,0,55","48,100,0,58","64,100,0,66","75,100,0,67","73,100,0,64","96,100,0,64",
// Color Book Block: 8
"18,10,0,0","26,18,0,0","28,16,0,0","35,18,0,0","20,6,0,0","32,11,0,0","30,20,0,0","61,48,0,0","35,22,0,0","47,28,0,0","31,12,0,0","48,21,0,0","68,52,0,0","92,71,0,0","61,43,0,0","75,47,0,0","46,23,0,0","72,36,0,0","100,93,0,5","100,89,0,5","100,81,0,10","100,65,0,8","100,60,0,8","100,53,0,0","100,89,0,24","100,89,0,25","100,80,0,27","100,63,0,23","100,55,0,33","100,49,0,15","100,88,0,37","100,90,0,39","100,78,0,40","100,63,0,34","100,47,0,53","100,45,0,38","100,81,0,67","100,88,0,66","100,71,0,63","100,52,0,65","100,34,0,70","100,34,0,64",
// Color Book Block: 9
"42,10,0,0","27,2,0,0","30,0,0,0","43,0,1,0","41,0,4,0","22,0,5,0","52,18,0,0","48,10,0,0","47,3,0,0","57,1,0,0","55,0,4,0","39,0,8,0","65,28,0,0","65,20,0,0","62,10,0,0","85,4,0,0","78,0,1,0","53,0,10,0","100,46,0,0","100,38,0,0","100,30,0,0","100,12,0,3","100,6,0,8","100,0,10,13","100,42,0,23","100,33,0,23","100,27,0,20","100,13,0,20","100,5,0,26","100,0,8,29","100,35,0,40","100,25,0,43","100,18,0,40","100,8,0,39","100,2,0,41","100,0,12,42","100,26,0,64","100,12,0,63","100,11,0,65","100,0,9,68","100,0,3,60","100,0,17,55",
// Color Book Block: 10
"33,0,11,0","40,0,14,0","37,0,16,0","41,0,17,0","25,0,14,0","30,0,18,0","51,0,18,0","49,0,18,0","47,0,21,0","52,0,24,0","33,0,18,0","43,0,25,0","72,0,26,2","71,0,26,0","62,0,27,0","81,0,38,0","48,0,26,0","68,0,41,0","100,0,30,21","100,0,32,0","94,0,39,0","100,0,45,5","87,0,44,0","100,0,58,9","100,0,27,40","100,0,30,22","100,0,40,10","100,0,40,28","100,0,50,9","100,0,48,36","100,0,25,51","100,0,30,50","100,0,38,33","100,0,40,48","100,0,48,25","100,0,51,50","100,0,30,64","100,0,35,68","100,0,40,66","100,0,40,69","100,0,48,45","100,0,58,67",
// Color Book Block: 11
"35,0,24,0","30,0,24,0","26,0,22,0","28,0,39,0","16,0,33,0","15,0,35,0","46,0,32,0","39,0,30,0","37,0,30,0","35,0,45,0","22,0,41,0","21,0,45,0","64,0,43,0","49,0,40,0","44,0,38,0","53,0,65,0","33,0,53,0","29,0,57,0","87,0,59,0","100,0,77,7","78,0,67,0","65,0,87,0","52,0,95,0","43,0,80,0","100,0,60,28","100,0,77,28","100,0,87,0","64,0,100,15","54,0,100,11","48,0,100,1","100,0,60,44","100,0,77,49","100,0,92,35","58,0,100,30","46,0,100,31","40,0,100,28","100,0,70,70","100,0,87,71","100,0,94,64","62,0,100,50","42,0,100,56","39,0,100,58",
// Color Book Block: 12
"11,0,47,0","9,0,49,0","5,0,42,0","5,0,45,0","0,0,7,18","0,2,7,18","16,0,57,0","13,0,60,0","8,0,54,0","7,0,60,0","0,0,8,24","0,3,8,28","21,0,75,0","19,0,70,0","12,0,67,0","9,0,73,0","0,0,9,30","0,5,9,37","26,0,95,0","24,0,84,0","16,0,86,0","11,0,95,0","0,0,10,39","0,4,12,45","21,0,100,19","21,0,100,9","15,0,100,11","3,0,100,27","4,0,15,50","0,4,13,58","18,0,100,30","14,0,100,30","9,0,100,25","4,0,100,39","0,0,22,70","0,16,32,69","18,0,100,49","14,0,100,42","9,0,100,36","11,0,100,52","0,25,70,90","0,35,75,89",
// Color Book Block: 13
"2,0,7,17","2,0,4,12","3,0,0,12","0,2,2,12","6,0,5,11","0,0,5,9","3,0,8,26","3,0,4,23","3,0,0,19","0,3,3,18","8,0,6,20","0,1,8,13","6,0,11,36","4,0,5,31","5,0,0,29","0,4,5,25","12,0,8,29","0,2,9,19","10,0,16,44","8,0,6,41","12,1,0,42","0,3,10,50","18,0,10,39","0,2,10,25","11,0,19,56","11,0,8,54","16,2,0,60","0,34,90,79","30,0,26,65","0,3,12,31","12,0,32,69","13,0,10,70","20,2,0,77","0,38,100,82","33,0,37,75","0,3,12,31","30,0,95,96","0,12,50,96","40,0,0,94","0,42,100,88","30,0,46,83","0,3,12,31",
// Color Book Block: 14
"0,1,9,32","1,0,2,7","2,0,3,30","81,84,100,0","0,10,100,71","0,5,100,68","0,2,9,35","1,0,4,10","2,0,4,35","79,81,100,0","0,4,100,50","0,2,100,44","0,1,12,43","2,0,4,16","4,0,5,41","73,77,100,0","0,6,61,38","0,8,100,29","0,1,15,50","3,0,4,21","8,0,7,47","35,39,54,0","0,3,44,28","13,14,59,0","0,1,17,59","2,0,3,26","9,0,7,59","27,28,43,0","0,2,31,20","10,10,50,0","0,5,20,66","2,0,3,26","10,0,10,66","17,18,31,0","0,1,25,13","7,8,40,0","0,5,20,66","2,0,3,26","10,0,10,66","10,10,21,0","0,1,19,8","4,4,28,0",
// Color Book Block: 15
"74,84,100,0","0,46,100,75","0,44,100,65","0,82,100,73","76,95,100,0","0,85,100,62","61,76,100,0","0,33,100,46","0,47,100,34","0,55,79,56","67,94,100,0","0,90,100,33","50,66,100,0","0,28,56,29","0,50,100,24","0,37,45,42","60,93,100,0","0,100,91,0","24,38,55,0","0,21,38,22","0,29,48,6","0,27,29,30","32,55,59,0","0,41,40,0","16,27,42,0","0,16,30,15","0,19,34,2","0,17,22,20","18,34,38,0","0,30,30,0","12,19,34,0","0,10,22,10","0,16,29,0","0,13,18,14","11,22,26,0","0,22,23,0","8,12,26,0","0,6,16,6","0,12,24,0","0,9,14,9","7,15,19,0","0,15,16,0",
// Color Book Block: 16
"0,71,100,70","0,61,100,76","0,55,100,77","76,100,98,0","67,100,74,0","75,100,80,0","0,78,100,58","0,60,100,64","0,53,53,53","65,100,97,0","53,94,49,0","61,93,63,0","0,76,100,45","0,56,100,57","0,39,31,34","59,100,90,0","40,95,27,0","50,68,45,0","0,38,31,9","0,31,28,16","0,29,23,26","14,45,32,0","12,45,12,0","35,54,33,0","0,25,19,4","0,22,19,7","0,20,17,15","9,35,24,0","8,37,10,0","22,36,24,0","0,21,16,2","0,16,14,4","0,15,14,9","5,26,17,0","5,27,8,0","11,21,14,0","0,16,13,0","0,12,11,2","0,10,10,5","2,19,12,0","1,18,5,0","6,12,8,0",
// Color Book Block: 17
"73,100,73,0","80,100,90,10","75,100,67,0","72,100,0,75","90,95,80,33","100,48,0,73","65,100,58,0","73,94,80,0","67,100,49,0","44,58,0,61","94,100,64,20","100,48,0,60","57,100,38,0","53,64,54,0","61,100,12,0","35,37,0,47","90,91,50,10","100,48,0,51","29,48,18,0","33,43,37,0","36,58,5,0","24,24,0,29","35,33,15,0","47,28,0,10","21,39,12,0","23,33,27,0","21,39,2,0","16,17,0,17","29,27,11,0","33,17,0,5","15,29,7,0","13,20,18,0","15,31,0,0","8,9,0,12","20,18,7,0","21,9,0,4","9,19,7,0","8,13,12,0","9,20,0,0","4,4,0,6","13,11,6,0","16,6,0,3",
// Color Book Block: 18
"100,35,0,85","100,12,0,81","100,0,10,85","81,0,58,86","60,0,67,78","85,0,75,82","54,24,0,53","100,18,0,71","91,0,5,54","42,0,11,67","62,0,41,64","44,0,25,53","45,22,0,33","100,21,0,65","46,0,2,34","24,0,2,48","63,0,40,58","30,0,17,37","30,14,0,27","42,18,0,20","30,0,4,24","14,0,3,33","29,0,17,29","20,0,13,28","17,7,0,17","30,13,0,15","21,0,4,15","10,0,4,22","20,0,12,20","14,0,10,19","12,4,0,12","21,8,0,11","14,0,4,7","8,0,3,14","16,0,11,14","10,0,8,11","7,1,0,8","14,3,0,8","10,0,4,6","7,0,3,9","11,0,8,9","7,0,7,6",
// Color Book Block: 19
"74,0,44,72","60,0,90,87","71,0,46,67","38,0,100,65","37,0,100,74","33,0,100,70","75,0,32,52","27,0,25,61","85,0,38,49","41,0,100,46","28,0,100,61","26,0,94,48","64,0,24,38","20,0,17,46","85,0,32,26","38,0,100,37","20,0,79,47","15,0,60,35","38,0,18,9","12,0,11,30","42,0,20,2","19,0,34,12","12,0,33,32","10,0,39,26","30,0,14,4","8,0,8,20","30,0,14,0","15,0,30,10","9,0,25,22","7,0,28,17","22,0,11,1","6,0,8,15","23,0,11,0","12,0,26,8","5,0,19,14","5,0,21,9","15,0,8,0","5,0,6,9","17,0,9,0","8,0,20,5","4,0,15,9","3,0,16,6",
// Color Book Block: 20
"17,0,100,59","12,0,100,72","2,0,25,0","1,0,22,2","1,0,19,5","8,0,8,6","14,0,100,39","11,0,100,50","2,0,35,0","2,0,29,3","1,0,26,8","13,0,10,10","18,0,100,16","5,0,64,35","3,0,40,0","3,0,39,4","2,0,32,11","19,0,13,17","14,0,63,5","3,0,46,28","4,0,55,0","3,0,49,6","3,0,43,16","28,0,18,27","10,0,53,3","2,0,28,16","5,0,69,1","5,0,69,11","3,0,69,27","40,0,24,38","7,0,42,2","1,0,23,11","5,0,90,5","4,0,95,18","2,0,100,39","85,0,64,64","5,0,33,1","0,0,17,7","2,0,100,12","1,0,100,28","8,0,100,44","100,0,98,81",
// Color Book Block: 21
"15,0,3,2","23,0,1,1","10,4,0,5","8,4,0,3","9,5,0,0","5,6,0,2","26,0,2,3","34,1,0,1","16,8,0,6","14,8,0,7","19,12,0,0","7,9,0,5","36,1,0,4","45,4,0,0","28,16,0,11","26,17,0,12","31,23,0,0","10,14,0,10","49,3,0,6","63,11,0,0","40,25,0,16","41,28,0,17","49,38,0,1","17,23,0,20","72,9,0,7","90,18,0,0","55,35,0,18","80,48,0,35","76,56,0,1","32,37,0,31","100,16,0,19","100,23,0,5","95,48,0,34","100,49,0,57","100,64,0,26","35,43,0,45","100,20,0,30","100,26,0,22","100,46,0,63","100,52,0,65","100,66,0,50","50,80,0,60",
// Color Book Block: 22
"0,12,2,2","0,12,3,5","0,12,6,5","0,11,10,5","0,14,12,0","0,12,10,0","0,21,4,4","0,17,4,7","0,18,8,7","0,18,15,7","0,22,17,1","0,21,16,0","0,33,6,6","0,23,4,9","0,24,10,10","0,25,20,11","0,32,24,2","0,32,23,0","0,46,10,9","0,31,7,15","0,34,13,17","0,30,23,18","0,42,32,5","0,46,34,0","0,64,14,14","0,43,9,25","0,45,14,27","0,46,33,30","0,60,44,9","0,60,46,0","0,100,25,23","0,63,12,34","0,68,20,43","0,61,47,43","0,75,55,24","0,77,60,1","0,100,32,34","0,100,29,53","0,100,37,60","0,100,67,55","0,100,78,33","0,100,78,7",
// Color Book Block: 23
"0,13,30,0","0,10,25,4","0,7,21,6","0,11,80,87","0,18,39,0","0,14,34,6","0,11,28,11","40,0,100,91","0,25,49,0","0,20,42,10","0,17,41,17","0,25,100,86","0,35,74,0","0,27,63,19","0,22,53,26","0,65,82,81","0,42,100,0","0,33,85,25","0,29,72,34","50,0,10,95","0,48,100,6","0,39,100,39","0,38,100,58","0,9,55,82","0,52,100,11","0,44,100,56","0,48,100,64","0,9,55,82"
];


function ColorProfileSpaces( ProfileToName, ValueNumber )
 {
  switch (ProfileToName.toLowerCase())
  {
   case "europe general purpose":
    if (ValueNumber == 1) {return "Europe General Purpose 2";}
    if (ValueNumber == 2) {return "sRGB IEC61966-2.1";}
    if (ValueNumber == 3) {return "Coated FOGRA27 (ISO 12647-2:2004)";}
   break;
   case "europe general purpose 3":
    if (ValueNumber == 1) {return "Europe General Purpose 3";}
	if (ValueNumber == 2) {return "sRGB IEC61966-2.1";}
	if (ValueNumber == 3) {return "Coated FOGRA39 (ISO 12647-2:2004)";}
   break;
   case "europe prepress":
    if (ValueNumber == 1) {return "Europe Prepress 2";}
	if (ValueNumber == 2) {return "Adobe RGB (1998)";}
	if (ValueNumber == 3) {return "Coated FOGRA27 (ISO 12647-2:2004)";}
   break;
   case "europe prepress 3":
    if (ValueNumber == 1) {return "Europe Prepress 3";}
	if (ValueNumber == 2) {return "Adobe RGB (1998)";}
	if (ValueNumber == 3) {return "Coated FOGRA39 (ISO 12647-2:2004)";}
   break;
   case "europe web internet":
    if (ValueNumber == 1) {return "Europe Web/Internet";}
	if (ValueNumber == 2) {return "sRGB IEC61966-2.1";}
	if (ValueNumber == 3) {return "Coated FOGRA27 (ISO 12647-2:2004)";}
   break;
   case "europe web internet 2": // strange that Adobe uses the same profile name for 2 different csf files
    if (ValueNumber == 1) {return "Europe Web/Internet";}
	if (ValueNumber == 2) {return "sRGB IEC61966-2.1";}
	if (ValueNumber == 3) {return "Coated FOGRA39 (ISO 12647-2:2004)";}
   break;
   case "japan general purpose":
    if (ValueNumber == 1) {return "Japan General Purpose 2";}
	if (ValueNumber == 2) {return "sRGB IEC61966-2.1";}
	if (ValueNumber == 3) {return "Japan Color 2001 (Coated)";}
   break;
   case "japan magazine":
    if (ValueNumber == 1) {return "Japan Magazine Advertisement Color";}
	if (ValueNumber == 2) {return "Adobe RGB (1998)";}
	if (ValueNumber == 3) {return "Japan Web Coated (Ad)";}
   break;
   case "japan newspaper":
    if (ValueNumber == 1) {return "Japan Color for NewsPaper";}
	if (ValueNumber == 2) {return "Adobe RGB (1998)";}
	if (ValueNumber == 3) {return "Japan Color 2002 Newspaper";}
   break;
   case "japan prepress":
    if (ValueNumber == 1) {return "Japan PrePress 2";}
	if (ValueNumber == 2) {return "Adobe RGB (1998)";}
	if (ValueNumber == 3) {return "Japan Color 2001 (Coated)";}
   break;
   case "japan web internet":
    if (ValueNumber == 1) {return "Japan Web/Internet";}
	if (ValueNumber == 2) {return "sRGB IEC61966-2.1";}
	if (ValueNumber == 3) {return "Japan Color 2001 (Coated)";}
   break;
   case "monitor color":
    if (ValueNumber == 1) {return "Monitor Color";}
	if (ValueNumber == 2) {return "Monitor RGB - sRGB IEC61966-2.1";}
	if (ValueNumber == 3) {return "U.S. Web Coated (SWOP) v2";}
   break;
   case "north america general purpose":
    if (ValueNumber == 1) {return "North America Gerneral Purpose 2";}
	if (ValueNumber == 2) {return "sRGB IEC61966-2.1";}
	if (ValueNumber == 3) {return "U.S. Web Coated (SWOP) v2";}
   break;
   case "north america newspaper":
    if (ValueNumber == 1) {return "North America Newspaper";}
	if (ValueNumber == 2) {return "Adobe RGB (1998)";}
	if (ValueNumber == 3) {return "US Newsprint (SNAP 2007)";}
   break;
   case "north america prepress":
    if (ValueNumber == 1) {return "North America Prepress 2";}
	if (ValueNumber == 2) {return "Adobe RGB (1998)";}
	if (ValueNumber == 3) {return "U.S. Web Coated (SWOP) v2";}
   break;
   case "north america web internet":
    if (ValueNumber == 1) {return "North America Web/Internet";}
	if (ValueNumber == 2) {return "sRGB IEC61966-2.1";}
	if (ValueNumber == 3) {return "U.S. Web Coated (SWOP) v2";}
   break;
   // cs3 profiles
   case "photoshop 5 default spaces":
    if (ValueNumber == 1) {return "Photoshop 5 Default Spaces";}
	if (ValueNumber == 2) {return "sRGB IEC61966-2.1";}
	if (ValueNumber == 3) {return "Photoshop 5 Default CMYK";}
   break;
   case "japan prepress defaults":
    if (ValueNumber == 1) {return "Japan Prepress Defaults";}
	if (ValueNumber == 2) {return "Adobe RGB (1998)";}
	if (ValueNumber == 3) {return "Japan Standard v2";}
   break;
   
   
   
  default:
    if (ValueNumber == 1) {return ProfileToName;}
	if (ValueNumber == 2) {return "No CS5 default RGB Color Space";}
	if (ValueNumber == 3) {return "No CS5 default CMYK Color Space";}
 } // case
} // function


function CreateMyColorChart()
{
// ********************************************************************************************************
// **                                                                                                    **
// ** init variables                                                                                     **
// **                                                                                                    **
// ********************************************************************************************************

var mmTOpt = 2.8344; //coeficiant

var PageWidth  = 210*mmTOpt;  // mm A4
var PageHeight = 297*mmTOpt; // mm A4
var PageRows = 7;     // rows for each color block
var PageColumns = 6;  // columns for each color block
var PageBlocks = 2;   // blocks on each page
var ColumnSpacer = 2*mmTOpt; // mm

var texthight = 8; // font heigth
var indent = 20; // space between c m y k 
var myfont = "Verdana"; // text font
var spacer = 1; // between color bottom and text
var offset = 0; // from left edge of color
var ColorCounter = 0;



// ********************************************************************************************************
// **                                                                                                    **
// ** create document                                                                                    **
// **                                                                                                    **
// ********************************************************************************************************

// 12 artboards = 2 rows of 6 columns
var CurrentDoc = app.documents.add ( DocumentColorSpace.CMYK, PageWidth, PageHeight,12,DocumentArtboardLayout.GridByRow,50,6); //add ([documentColorSpace][, width][, height][, numArtBoards][, artboardLayout][, artboardSpacing][, artboardRowsOrCols])


var artboardRef = CurrentDoc.artboards;
for ( var i = 0; i < artboardRef.length; i++ ) 
  {

var RulerLeft = artboardRef[i].artboardRect[0];
var RulerTop  = artboardRef[i].artboardRect[1] ; 

 
var rowitems = 0;
columnitems = 0;
var top = RulerTop + ( -45*mmTOpt );
var left = RulerLeft + ( 20*mmTOpt );
var width = 28*mmTOpt;
var height = 10*mmTOpt;
var PageWidth = 210*mmTOpt;
var PageHeight = 297*mmTOpt;
var now = new Date();


//add text to artboard
var cTextRef = CurrentDoc.textFrames.add();
cTextRef.textRange.characterAttributes.textFont=app.textFonts.getByName(myfont); 
cTextRef.textRange.characterAttributes.size = 27;
cTextRef.contents = "CMYK Process Color Simulation Guide";
cTextRef.left = RulerLeft + 55;
cTextRef.top  = RulerTop - 64;
//add text to artboard
var cTextRef = CurrentDoc.textFrames.add();
cTextRef.textRange.characterAttributes.textFont=app.textFonts.getByName(myfont); 
cTextRef.textRange.characterAttributes.size = 9.22;
cTextRef.contents = "first number = % Cyan; second number = % Magenta; third number = % Yellow; fourth number = % Black";
cTextRef.left = RulerLeft + 57;
cTextRef.top  = RulerTop - 94;
//add text to artboard
var cTextRef = CurrentDoc.textFrames.add();
cTextRef.textRange.characterAttributes.textFont=app.textFonts.getByName(myfont); 
cTextRef.textRange.characterAttributes.size = 8;
cTextRef.contents = "CMYK colors used in this document are printer, ink and paper depending process simulations and, if printed on an";
cTextRef.left = RulerLeft + 57;
cTextRef.top  = RulerTop - 790;
//add text to artboard
var cTextRef = CurrentDoc.textFrames.add();
cTextRef.textRange.characterAttributes.textFont=app.textFonts.getByName(myfont); 
cTextRef.textRange.characterAttributes.size = 8;
cTextRef.contents = "other printer, with other ink, on other paper or displayed on the screen, may not match colors in this document. ";
cTextRef.left = RulerLeft + 57;
cTextRef.top  = RulerTop - 798;
//add text to artboard
var cTextRef = CurrentDoc.textFrames.add();
cTextRef.textRange.characterAttributes.textFont=app.textFonts.getByName(myfont); 
cTextRef.textRange.characterAttributes.size = 6;
cTextRef.contents = "document created: " + dateFormat(now, "dddd, mmmm dS, yyyy") + " - based on Pantone Color Look-Up Table © Pantone, Inc., 1992, 1999.";
cTextRef.left = RulerLeft + 57;
cTextRef.top  = RulerTop - 810;
//add text PAGENUMBER
var cTextRef = CurrentDoc.textFrames.add();
cTextRef.textRange.characterAttributes.textFont=app.textFonts.getByName(myfont); 
cTextRef.textRange.characterAttributes.size = 6;
var ABNumber = i+1;
cTextRef.contents = "Page: "+ ABNumber;
cTextRef.left = RulerLeft + ( 20*mmTOpt ) + (width * PageColumns) + ( ColumnSpacer * (PageColumns-1)) - cTextRef.width;
cTextRef.top  = RulerTop - 816;
//add text to artboard
var cTextRef = CurrentDoc.textFrames.add();
cTextRef.textRange.characterAttributes.textFont=app.textFonts.getByName(myfont); 
cTextRef.textRange.characterAttributes.size = 6;
cTextRef.contents = "www.no-nonsens.nl © " + dateFormat(now, "yyyy") + " all rights reserved - released under Creative Commons Attribution-NoDerivatives 4.0 International License."
cTextRef.left = RulerLeft + 57;
cTextRef.top  = RulerTop - 816;



//add COLOR PROFILE
var cTextRef = CurrentDoc.textFrames.add();
cTextRef.textRange.characterAttributes.textFont=app.textFonts.getByName(myfont); 
cTextRef.textRange.characterAttributes.size = 16;
cTextRef.contents = CurrentDocumentColorProfileName;
cTextRef.left = RulerLeft + ( 20*mmTOpt ) + (width * PageColumns) + ( ColumnSpacer * (PageColumns-1)) - cTextRef.width;
cTextRef.top  = RulerTop - 25;

//add RGB WORKING SPACE
var cTextRef = CurrentDoc.textFrames.add();
cTextRef.textRange.characterAttributes.textFont=app.textFonts.getByName(myfont); 
cTextRef.textRange.characterAttributes.size = 8;
cTextRef.contents = "RGB working space: " + RGBProfile;
cTextRef.left = RulerLeft + ( 20*mmTOpt ) + (width * PageColumns) + ( ColumnSpacer * (PageColumns-1)) - cTextRef.width;
cTextRef.top  = RulerTop - 43;

//add CMYK WORKING SPACE
var cTextRef = CurrentDoc.textFrames.add();
cTextRef.textRange.characterAttributes.textFont=app.textFonts.getByName(myfont); 
cTextRef.textRange.characterAttributes.size = 8;
cTextRef.contents = "CMYK working space: " + CMYKProfile;
cTextRef.left = RulerLeft + ( 20*mmTOpt ) + (width * PageColumns) + ( ColumnSpacer * (PageColumns-1)) - cTextRef.width;
cTextRef.top  = RulerTop - 52;

                       
                       


if (i == 11) { PageColumns = 4}; // last page has less colors

ToStart = ColorCounter;
ToEnd   = ColorCounter + 84; 

if (ToEnd >= DefaultColorBook.length-1) {ToEnd = DefaultColorBook.length-1;}



//for (k=0; k < DefaultColorBook.length; k++) 
for (k = ToStart; k < ToEnd; k++) 
 {
 
 var rect = CurrentDoc.pathItems.rectangle (top, left, width, height);
 
 left = left + ( ColumnSpacer + width); 
 rowitems = rowitems + 1; 
 if (rowitems == PageColumns) 
   {
    left = RulerLeft + (20*mmTOpt); 
	top = top - (16*mmTOpt); 
	rowitems = 0; 
	columnitems = columnitems + 1;
   }
 
 if (columnitems == 7) // extra space between 2 blocks
  {
   columnitems = 0; top = top - (6*mmTOpt); 
  }
 
 var MyColor = DefaultColorBook[k].split(",");
 
rect.fillColor.cyan = MyColor[0];
rect.fillColor.magenta = MyColor[1];
rect.fillColor.yellow = MyColor[2];
rect.fillColor.black = MyColor[3];

var noColor = new NoColor();
rect.strokeColor = noColor;


var cTextRef = CurrentDoc.textFrames.add();
cTextRef.textRange.characterAttributes.textFont=app.textFonts.getByName(myfont); 
cTextRef.textRange.characterAttributes.size = texthight;
cTextRef.contents = MyColor[0]+',  '+MyColor[1]+',  '+MyColor[2]+',  '+MyColor[3];
cTextRef.left = offset+rect.left;
cTextRef.top = rect.top-rect.height-spacer;



  }
  
ColorCounter = ColorCounter + 84;   
  
redraw();

 } // artboard loop
 
} // end function
 
 
 
function exportFileToPDF () 
 {

 var saveFile = "none";
 saveFile = File.saveDialog('Please choose a folder and specify a file name','Adobe PDF document:*.pdf,All files:*.*');
 if ( saveFile != "none" )
 {
  try
    {
     var doc = app.activeDocument;
     if ( app.documents.length > 0 ) 
        {
         var saveMe = new File ( saveFile );
         saveOpts = new PDFSaveOptions();
         saveOpts.acrobatLayers = false;
         saveOpts.pDFXStandard = PDFXStandard.PDFX32002;
         saveOpts.pDFXStandardDescription = "PDF/X-3:2002";
         saveOpts.viewAfterSaving = true;
         saveOpts.generateThumbnails = true;
         saveOpts.preserveEditability = true;
         saveOpts.generateThumbnails = true;
         saveOpts.preserveEditability = true;
		 saveOpts.colorProfileID = ColorProfile.LEAVEPROFILEUNCHANGED;
         doc.saveAs( saveMe, saveOpts );
        } // save
  	} // try
   catch(err)
	{
     alert("An error occured saving this document " + path +".\n(" + err + ").\n\nFunction: exportFileToPDF.");
    }	
  
   } // if  
 
 } // function

 
 
 
 
 // *******************************************************************************************************************************
// *******************************************************************************************************************************
// *******************************************************************************************************************************
// *******************************************************************************************************************************
// *******************************************************************************************************************************
// *******************************************************************************************************************************
// *******************************************************************************************************************************
// *******************************************************************************************************************************
// *******************************************************************************************************************************
// *******************************************************************************************************************************
// *******************************************************************************************************************************
// *******************************************************************************************************************************

 var msis_message_1 = "\nThis script creates a 12 page (930 colors) A4 CMYK color guide in the selected ICC Color Profile. "+
                     "After color guide creation the guide can be exported to PDF as PDF/X-3:2002."; 


// ********************************************************************************************************
// **                                                                                                    **
// ** building and showing main dialog                                                                   **
// **                                                                                                    **
// ********************************************************************************************************
function color_chart_dialog() {
   
   // Export dialog
    color_chart_dialog_window = new Window('dialog', 'Create CMYK color Guide  -  v1.02'); 

    // PANEL with usage instructions
    color_chart_dialog_window.MessagePanel = color_chart_dialog_window.add('panel', undefined, 'Create CMYK color Guide'); 
    // GROUP
    var Message_Group = color_chart_dialog_window.MessagePanel.add('group', undefined, '')
    Message_Group.orientation = 'column';
    Message_Group.alignment = [ScriptUI.Alignment.LEFT, ScriptUI.Alignment.TOP]
	// Labels
    var Message_Group_label_1 = Message_Group.add('statictext', undefined,  msis_message_1, {multiline:true}); 
    Message_Group_label_1.size = [500,50];

	
   // get color profiles	
   var Color_Profile_Array = app.colorSettingsList;
   // var Color_Profile_Array = csList.split(","); //unescape( csList.split(",") ) ;
   
   
   var Show_Profiles_Array = new Array;
   
   
   
   for (s = 0; s < Color_Profile_Array.length; s++)
   {
    var thisProfile = unescape( Color_Profile_Array[s] );
    thisProfile = thisProfile.substring( thisProfile.lastIndexOf('/') + 1);    // strip path
    thisProfile = thisProfile.substring (0, thisProfile.lastIndexOf('.') ); // strip .
	thisProfile = ColorProfileSpaces( thisProfile, 1 ); // get adobe name for the csf file
    Show_Profiles_Array.push( thisProfile );
   }
   

    // PANEL with Export Options
	color_chart_dialog_window.OptionsPanel =  color_chart_dialog_window.add ('panel', undefined, 'Select an ICC Color Profile:');
    // GROUP
	var Options_Group1 = color_chart_dialog_window.OptionsPanel.add('group', undefined, '')
	Options_Group1.alignChildren = "left";
	Options_Group1.size = [500,25];
	Options_Group1.orientation = 'row';
	
	color_chart_dialog_window.myProfileSettings = Options_Group1.add ("dropdownlist", undefined,  Show_Profiles_Array );
	
	
	
   // set current profile default (if present)	
   for (s = 0; s < Show_Profiles_Array.length; s++)
   {
	if ( Show_Profiles_Array[s] == ColorProfileName )
	 {
      color_chart_dialog_window.myProfileSettings.selection = s; 	 
	 }
	}

	
	
  


    // Buttons don't have a PANEL
    // GROUP
    Button_Group = color_chart_dialog_window.add('group', undefined, ''); 
    Button_Group.orientation = 'row'

    Button_Group.okBtn = Button_Group.add('button', undefined, 'Create Color Guide', {name:'ok'});
	
    Button_Group.pdfBtn = Button_Group.add('button', undefined, 'Create PDF/X3:2002');
	Button_Group.pdfBtn.enabled = false;
	Button_Group.pdfBtn.onClick = function() { Button_Group.pdfBtn.enabled = false; color_chart_dialog_window.update(); exportFileToPDF(); color_chart_dialog_window.close(); };
		
	Button_Group.closeBtn = Button_Group.add('button', undefined, 'Close', {name:'cancel'});
	Button_Group.closeBtn.onClick = function() {  color_chart_dialog_window.close(); };
	
    Button_Group.aboutBtn = Button_Group.add('button', undefined, 'About');
    Button_Group.aboutBtn.onClick = function() { alert(msis_message_2); };		
	
    Button_Group.okBtn.onClick = function() 
	             {
				 
				   s = color_chart_dialog_window.myProfileSettings.selection.index;
                   color_chart_dialog_window.myProfileSettings.enabled = false;	
				   Button_Group.okBtn.enabled = false;
				   Button_Group.closeBtn.enabled = false;
				   Button_Group.pdfBtn.enabled = false;	
				   Button_Group.aboutBtn.enabled = false;
				   // repaint buttons so they get disabled on update (stupid that this is needed)
				   Button_Group.closeBtn.text = '.';
     			   Button_Group.aboutBtn.text = '.';	
				   Button_Group.closeBtn.text = 'Close';
     			   Button_Group.aboutBtn.text = 'About';				   
				   color_chart_dialog_window.update(); 
				   
				   // set color mode for new document
				   app.loadColorSettings( File( Color_Profile_Array[s]) );
				   // get csf file name
                   var thisProfile = unescape( Color_Profile_Array[s] );
                       thisProfile = thisProfile.substring( thisProfile.lastIndexOf('/') + 1);    // strip path
                       thisProfile = thisProfile.substring (0, thisProfile.lastIndexOf('.') ); // strip .
                       RGBProfile  = ColorProfileSpaces( thisProfile, 2 ); // get rgb working space
                       CMYKProfile = ColorProfileSpaces( thisProfile, 3 ); // get cmyk working space
				   CurrentDocumentColorProfileName =  Show_Profiles_Array[s];
				   
				   CreateMyColorChart();

				   Button_Group.pdfBtn.enabled    = true;
				   Button_Group.closeBtn.enabled  = true;	
				   Button_Group.aboutBtn.enabled  = true;				   
				 };

					 
				 
    color_chart_dialog_window.show();
}


 
color_chart_dialog();

 
 
 
 
 
 
 
 
 
 
 
 
 